﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

// Auteures : Stéphanie Besner-Depocas, Jinane Fahs et Valantina Jeji
// MAT4812 Explorations mathématiques à l'aide de l'informatique
// UQÀM Hiver 2010

namespace ProjetFinalMAT4812
{
    public partial class FormPrincipal : Form
    {
        public FormPrincipal()
        {
            InitializeComponent();
            VideChamps();
        }

        private void quitterToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Close();    // Permet de fermer l'application.
        }

        private void VideChamps()       // Réinitialise l'application.
        {
            textBoxNombreEntree.Text = "";
            textBoxNombreSortie.Text = "";
            RBdepartBinaire.Checked = false;
            RBdepartDecimale.Checked = true;
            RBdepartHexadecimale.Checked = false;
            RBarriveeArabe.Checked = false;
            RBarriveeBinaire.Checked = false;
            RBarriveeDecimale.Checked = true;
            RBarriveeHexadecimale.Checked = false;
            RBarriveeLettres.Checked = false;
            RBarriveeMaya.Checked = false;
            RBarriveeRomaine.Checked = false;
        }

        private void nouveauCalculToolStripMenuItem_Click(object sender, EventArgs e)
        {
            VideChamps();
        }

        private bool NombreDecimalValide(string texte)
        { 
            bool valide = true;

            for (int i = 0; i != texte.Length && valide; ++i)
            {
                if ( ! Char.IsDigit(texte[i]))      // Vérifie que le nombre en entrée contient uniquement
                    valide = false;                  // des chiffres.
            }

            return valide;
        }

        private bool NombreBinaireValide(string texte)
        {
            bool valide = true;

            for (int i = 0; i != texte.Length && valide; ++i)
            {
                if (texte[i] != '0' && texte[i] != '1')     // Vérifie que le nombre en entrée contient
                    valide = false;                          // seulement les chiffres 0 ou 1.    
            }

            return valide;
        }

        private bool NombreHexadecimalValide(string texte)
        {
            bool valide = true;

            for (int i = 0; i != texte.Length && valide; ++i)
            {
                // Vérifie que le nombre en entrée contient uniquement des chiffres ou les 6 premières
                 // lettres de l'alphabet.
                if ( ! Char.IsDigit(texte[i]) && texte[i] != 'A' && texte[i] != 'B' &&
                    texte[i] != 'C' && texte[i] != 'D' && texte[i] != 'E' &&
                    texte[i] != 'F')
                    valide = false;
            }

            return valide;
        }

        private bool NombreRomainValide(string texte)
        {
            bool valide = true;

            for (int i = 0; i != texte.Length && valide; ++i)
            {
                // Vérifie que le nombre en entrée contient seulement les lettres représentant des chiffres
                 // romains.
                if (texte[i] != 'C' && texte[i] != 'D' && texte[i] != 'I' && texte[i] != 'L' && 
                    texte[i] != 'M' && texte[i] != 'V' && texte[i] != 'X')
                    valide = false;
            }

            return valide;
        }

        bool NombreRomainTropGrand(string nb)
        {
            int cpt = 0;

            for (int i = 0; i != nb.Length; ++i)
            {
                if (nb[i] == 'M')       // Compte le nombre de M du nombre en entrée écrit en notation
                    ++cpt;               // romaine.
            }

            return cpt > 4;
        }

        private bool VérificationErreurs()  // Renvoie différents messages d'erreur.
        {
            bool valide = true;

            if (textBoxNombreEntree.Text == "")     // Aucun nombre n'a été entré par l'utilisateur.
            {
                FormMessage f1 = new FormMessage("Le nombre en entrée est manquant.");
                f1.ShowDialog();
                valide = false;
            }
            else
            if (RBdepartDecimale.Checked && ! NombreDecimalValide(textBoxNombreEntree.Text))
            {
                FormMessage f2 = new FormMessage("Le nombre en entrée doit être en notation décimale.");
                f2.ShowDialog();
                valide = false;
            }
            else
            if (RBdepartBinaire.Checked && ! NombreBinaireValide(textBoxNombreEntree.Text))
            {
                FormMessage f3 = new FormMessage("Le nombre en entrée doit être en notation binaire.");
                f3.ShowDialog();
                valide = false;
            }
            else
            if (RBdepartHexadecimale.Checked && ! NombreHexadecimalValide(textBoxNombreEntree.Text))
            {
                FormMessage f4 = new FormMessage("Le nombre en entrée doit être en notation hexadécimale.");
                f4.ShowDialog();
                valide = false;
            }
            else
            if (RBdepartRomaine.Checked && ! NombreRomainValide(textBoxNombreEntree.Text))
            {
                FormMessage f5 = new FormMessage("Le nombre en entrée doit être en notation romaine.");
                f5.ShowDialog();
                valide = false;
            }
            else
            if (RBdepartDecimale.Checked && Convert.ToInt64(textBoxNombreEntree.Text) > 4999)
            {
                FormMessage f6 = new FormMessage("Le nombre en entrée doit être inférieur à 5000.");
                f6.ShowDialog();
                valide = false;
            }
            else
            if (RBdepartBinaire.Checked && Convert.ToInt64(textBoxNombreEntree.Text) > 1001110001000)
            {
                FormMessage f7 = new FormMessage("Le nombre en entrée doit être inférieur à 1111111111111.");
                f7.ShowDialog();
                valide = false;
            }
            else
            if (RBdepartRomaine.Checked && NombreRomainTropGrand(textBoxNombreEntree.Text))
            {
                FormMessage f9 = new FormMessage("Le nombre en entrée doit être inférieur à MMMMM.");
                f9.ShowDialog();
                valide = false;
            }

            return valide;
        }

        private void ConversionDecimaleRomaine()
        {
            int nombreEntrée = Convert.ToInt32(g_nombreEntrée);  // Convertit le nombre en entrée en
                                                                  // nombre entier.
            int millier = nombreEntrée / 1000;      // Compte le nombre de milliers.
            nombreEntrée %= 1000;
            int centaine = nombreEntrée / 100;      // Compte le nombre de centaines.
            nombreEntrée %= 100;
            int dizaine = nombreEntrée / 10;        // Compte le nombre de dizaines.
            nombreEntrée %= 10;

            for (int i = 0; i != millier; ++i)
            {
                g_nombreSortie += 'M';              // Ajoute un M pour chaque millier.
            }

            if (centaine == 9)                      
            { 
                g_nombreSortie += "CM";             // Ajoute CM lorsque le nombre de centaines est égal à 9.
                centaine -= 9;
            }


            if ((centaine >= 5) && (centaine <= 8))
            {
                g_nombreSortie += 'D';              // Ajoute D lorsque le nombre de centaines est compris entre
                centaine -= 5;                       // 5 et 8 inclusivement.
            }

            if (centaine == 4)
            {
                g_nombreSortie += "CD";             // Ajoute CD lorsque le nombre de centaines est égal à 4.
                centaine -= 4;
            }

            if ((centaine >= 1) && (centaine <= 3))
            {
                for (int i = 0; i != centaine; ++i)
                {
                    g_nombreSortie += 'C';          // Ajoute un C pour chaque autre centaine.
                }
            }

            if (dizaine == 9)
            {
                g_nombreSortie += "XC";             // Ajoute XC lorsque le nombre de dizaines est égal à 9.
                dizaine -= 9;       
            }


            if ((dizaine >= 5) && (dizaine <= 8))
            {
                g_nombreSortie += 'L';              // Ajoute L lorsque le nombre de dizaines est compris entre
                dizaine -= 5;                        // 5 et 8 inclusivement.
            }

            if (dizaine == 4)
            {
                g_nombreSortie += "XL";             // Ajoute XL lorsque le nombre de dizaines est égal à 4.
                dizaine -= 4;
            }

            if ((dizaine >= 1) && (dizaine <= 3))
            {
                for (int i = 0; i != dizaine; ++i)
                {
                    g_nombreSortie += 'X';          // Ajoute un X pour chaque autre dizaine.
                }
            }

            if (nombreEntrée == 9)
            {
                g_nombreSortie += "IX";             // Ajoute IX lorsque le nombre d'unités est égal à 9.
                nombreEntrée -= 9;
            }


            if ((nombreEntrée >= 5) && (nombreEntrée <= 8))
            {
                g_nombreSortie += 'V';              // Ajoute V lorsque le nombre d'unités est compris entre
                nombreEntrée -= 5;                   // 5 et 8 inclusivement.
            }

            if (nombreEntrée == 4)
            {
                g_nombreSortie += "IV";             // Ajoute IV lorsque le nombre d'unités est égal à 4.
                nombreEntrée -= 4;
            }

            if ((nombreEntrée >= 1) && (nombreEntrée <= 3))
            {
                for (int i = 0; i != nombreEntrée; ++i)
                {
                    g_nombreSortie += 'I';          // Ajoute un I pour chaque autre unité.
                }
            }
        }

        private void ConversionDecimaleBinaire()
        {
            int nombreEntrée = Convert.ToInt32(g_nombreEntrée);     // Convertit le nombre en entrée en
            string nombreSortie = "";                                // nombre entier.

            while (nombreEntrée != 0)
            {
                int reste = nombreEntrée % 2;       // Nombre en entrée modulo 2 pour trouver le reste de
                nombreSortie += reste;               // la division. Ce reste est ajouté au nombre à la sortie.
                nombreEntrée /= 2;
            }

            for (int i = nombreSortie.Length - 1; i >= 0; --i)   // Récrit le nombre en notation binaire 
                g_nombreSortie += nombreSortie[i];                // dans le bon sens.
        }

        private void ConversionDecimaleHexadecimale()
        {
            int nombreEntrée = Convert.ToInt32(g_nombreEntrée);     // Convertit le nombre en entrée en
            string nombreSortie = "";                                // nombre entier.

            while (nombreEntrée != 0)
            {
                int reste = nombreEntrée % 16;      // Nombre en entrée modulo 16 pour trouver le reste de
                                                     // la division. Ce reste est ajouté au nombre à la sortie.
                switch (reste)
                {
                    case 10: nombreSortie += 'A'; break;    // Lorsque le reste est compris entre 10 et 15,
                    case 11: nombreSortie += 'B'; break;     // il faut le remplacer par sa lettre correspondante.
                    case 12: nombreSortie += 'C'; break;
                    case 13: nombreSortie += 'D'; break;
                    case 14: nombreSortie += 'E'; break;
                    case 15: nombreSortie += 'F'; break;
                    default: nombreSortie += reste; break;
                }

                nombreEntrée /= 16;
            }

            for (int i = nombreSortie.Length - 1; i >= 0; --i)  // Récrit le nombre en notation hexadécimale
                g_nombreSortie += nombreSortie[i];               // dans le bon sens.
        }

        private void ConversionDecimaleLettres()
        {
            int chiffre = Convert.ToInt32(g_nombreEntrée);  // Convertit le nombre en entrée en nombre entier.

            int centaine, dizaine, unite, reste, y;
            bool dix = false;
            bool soixanteDix = false;
            string lettre = "";

            reste = (int)chiffre / 1;

            for (int i = 1000000000; i >= 1; i /= 1000)
            {
                y = reste / i;
                if (y != 0)
                {
                    centaine = y / 100;                             // Compte le nombre de centaines, de
                    dizaine = (y - centaine * 100) / 10;             // dizaines et d'unités.
                    unite = y - (centaine * 100) - (dizaine * 10);
                    
                    switch (centaine)  // Remplace le nombre de centaines par son équivalent en lettres.
                    {                   // Lorsque les nombre de dizaines et d'unités sont égaux à 0, on
                        case 0:         // met un "s" à cent (quand le nombre de centaines est plus grand
                            break;      // ou égal à 2).
                        case 1:
                            lettre += "cent ";
                            break;
                        case 2:
                            if ((dizaine == 0) && (unite == 0)) lettre += "deux cents ";
                            else lettre += "deux cent ";
                            break;
                        case 3:
                            if ((dizaine == 0) && (unite == 0)) lettre += "trois cents ";
                            else lettre += "trois cent ";
                            break;
                        case 4:
                            if ((dizaine == 0) && (unite == 0)) lettre += "quatre cents ";
                            else lettre += "quatre cent ";
                            break;
                        case 5:
                            if ((dizaine == 0) && (unite == 0)) lettre += "cinq cents ";
                            else lettre += "cinq cent ";
                            break;
                        case 6:
                            if ((dizaine == 0) && (unite == 0)) lettre += "six cents ";
                            else lettre += "six cent ";
                            break;
                        case 7:
                            if ((dizaine == 0) && (unite == 0)) lettre += "sept cents ";
                            else lettre += "sept cent ";
                            break;
                        case 8:
                            if ((dizaine == 0) && (unite == 0)) lettre += "huit cents ";
                            else lettre += "huit cent ";
                            break;
                        case 9:
                            if ((dizaine == 0) && (unite == 0)) lettre += "neuf cents ";
                            else lettre += "neuf cent ";
                            break;
                    }

                    switch (dizaine)    // Remplace le nombre de dizaines par son équivalent en lettres.
                    {
                        case 0:
                            break;
                        case 1:
                            dix = true;
                            break;
                        case 2:
                            if (unite == 0 || unite == 1) lettre += "vingt ";
                            else lettre += "vingt-";
                            break;
                        case 3:
                            if (unite == 0 || unite == 1) lettre += "trente ";
                            else lettre += "trente-";
                            break;
                        case 4:
                            if (unite == 0 || unite == 1) lettre += "quarante ";
                            else lettre += "quarante-";
                            break;
                        case 5:
                            if (unite == 0 || unite == 1) lettre += "cinquante ";
                            else lettre += "cinquante-";
                            break;
                        case 6:
                            if (unite == 0 || unite == 1) lettre += "soixante ";
                            else lettre += "soixante-";
                            break;
                        case 7:
                            dix = true;
                            soixanteDix = true;
                            if (unite == 0) lettre += "soixante-";
                            else if (unite == 1) lettre += "soixante ";
                            else lettre += "soixante";
                            break;
                        case 8:
                            if (unite == 0) lettre += "quatre-vingts ";
                            else lettre += "quatre-vingt-";
                            break;
                        case 9:
                            dix = true;
                            if (unite == 0) lettre += "quatre-vingt-";
                            else lettre += "quatre-vingt";
                            break;
                    }

                    switch (unite)   // Remplace le nombre d'unités par son équivalent en lettres.
                    {
                        case 0:
                            if (dix) lettre += "dix ";
                            break;
                        case 1:
                            if (soixanteDix) lettre += "et onze ";
                            else
                                if (dix) lettre += "-onze ";
                                else if ((dizaine != 1 && dizaine != 0 && dizaine != 8)) lettre += "et un ";
                                else lettre += "un ";
                            break;
                        case 2:
                            if (dix) lettre += "-douze ";
                            else lettre += "deux ";
                            break;
                        case 3:
                            if (dix) lettre += "-treize ";
                            else lettre += "trois ";
                            break;
                        case 4:
                            if (dix) lettre += "-quatorze ";
                            else lettre += "quatre ";
                            break;
                        case 5:
                            if (dix) lettre += "-quinze ";
                            else lettre += "cinq ";
                            break;
                        case 6:
                            if (dix) lettre += "-seize ";
                            else lettre += "six ";
                            break;
                        case 7:
                            if (dix) lettre += "-dix-sept ";
                            else lettre += "sept ";
                            break;
                        case 8:
                            if (dix) lettre += "-dix-huit ";
                            else lettre += "huit ";
                            break;
                        case 9:
                            if (dix) lettre += "-dix-neuf ";
                            else lettre += "neuf ";
                            break;
                    }

                    switch (i)
                    {
                       case 1000:
                            lettre += "mille ";
                            break;
                    }
                }
                reste -= y * i;
                dix = false;
                soixanteDix = false;
            }

            if (lettre.Length == 0) lettre += "zéro";

            if (lettre.StartsWith("un mille"))
            {
                lettre = lettre.Remove(0, 3);  // Supprime les 3 premiers caractères pour obtenir "mille"
            }                                   // au lieu de "un mille".

            g_nombreSortie = lettre;          // Renvoie le nombre final en lettres
        }

        private void ConversionDecimaleArabe()
        {
            string nombreEntrée = g_nombreEntrée;
            string nombreSortie = "";

            for (int i = 0; i != nombreEntrée.Length; ++i)
            {
                switch (nombreEntrée[i])
                {
                    case '0': nombreSortie += "\u0660"; break;      // Remplace chacun des chiffres du nombre
                    case '1': nombreSortie += "\u0661"; break;       // en entrée par son équivalent arabe à 
                    case '2': nombreSortie += "\u0662"; break;       // l'aide de l'Unicode.
                    case '3': nombreSortie += "\u0663"; break;
                    case '4': nombreSortie += "\u0664"; break;
                    case '5': nombreSortie += "\u0665"; break;
                    case '6': nombreSortie += "\u0666"; break;
                    case '7': nombreSortie += "\u0667"; break;
                    case '8': nombreSortie += "\u0668"; break;
                    case '9': nombreSortie += "\u0669"; break;
                }
            }

            g_nombreSortie = nombreSortie;
        }

        private void ConversionDecimaleMaya()
        {
            g_nombreSortie = "...";     // La boite du nombre à la sortie ne sera pas utilisée dans ce cas-ci.
            FormMaya f = new FormMaya(Convert.ToInt32(g_nombreEntrée));
            f.ShowDialog();             // La conversion sera affichée dans une autre fenêtre.
        }

        private void ConversionBinaireDecimale()
        {
            string nombreEntrée = g_nombreEntrée;
            long nombreSortie = 0;

            // Pour chacun des chiffres du nombre en entrée, on le multiplie par 2 exposant sa position
             // dans le nombre - 1. Chaque résultat est additionné pour former le nombre à la sortie.
            for (int i = 0; i != nombreEntrée.Length; ++i)      
            {                                                   
                int chiffre = Convert.ToInt32(nombreEntrée[i].ToString());
                nombreSortie += chiffre * (long)Math.Pow(2, nombreEntrée.Length - 1 - i);
            }

            g_nombreSortie = nombreSortie.ToString();
        }

        private void ConversionBinaireRomaine()
        {
            ConversionBinaireDecimale();

            g_nombreEntrée = g_nombreSortie;        // Effectue la conversion vers la notation décimale dans 
            g_nombreSortie = "";                     // un premier temps, puis la conversion vers la notation
                                                     // romaine. Cela simplifie grandement la programmation.
            ConversionDecimaleRomaine();
        }

        private void ConversionBinaireHexadecimale()
        {
            ConversionBinaireDecimale();

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleHexadecimale();
        }

        private void ConversionBinaireLettres()
        {
            ConversionBinaireDecimale();

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleLettres();
        }

        private void ConversionBinaireArabe()
        {
            ConversionBinaireDecimale();

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleArabe();
        }

        private void ConversionBinaireMaya()
        {
            ConversionBinaireDecimale();

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleMaya();
        }

        private void ConversionHexadecimaleDecimale()
        {
            string nombreEntrée = g_nombreEntrée;
            int nombreSortie = 0;
            int chiffre = 0;

            for (int i = 0; i != nombreEntrée.Length; ++i)
            {
                switch (nombreEntrée[i])
                {
                    case 'A': chiffre = 10; break;      // Même principe que la conversion binaire vers
                    case 'B': chiffre = 11; break;       // décimale, sauf que l'on doit tenir compte des
                    case 'C': chiffre = 12; break;       // lettres A à F qu'il faut remplacer par leur valeur
                    case 'D': chiffre = 13; break;       // en notation décimale.
                    case 'E': chiffre = 14; break;
                    case 'F': chiffre = 15; break;
                    default: chiffre = Convert.ToInt32(nombreEntrée[i].ToString()); break;
                }

                nombreSortie += chiffre * (int)Math.Pow(16, nombreEntrée.Length - 1 - i);
            }

            g_nombreSortie = nombreSortie.ToString();
        }

        private void ConversionHexadecimaleBinaire()
        {
            ConversionHexadecimaleDecimale();       // On se sert de ce qui a déjà été fait précédemment.

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleBinaire();
        }

        private void ConversionHexadecimaleRomaine()
        {
            ConversionHexadecimaleDecimale();

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleRomaine();
        }

        private void ConversionHexadecimaleLettres()
        {
            ConversionHexadecimaleDecimale();

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleLettres();
        }

        private void ConversionHexadecimaleArabe()
        {
            ConversionHexadecimaleDecimale();

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleArabe();
        }

        private void ConversionHexadecimaleMaya()
        {
            ConversionHexadecimaleDecimale();

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleMaya();
        }

        private void ConversionRomaineDecimale()
        {
            string nombreEntrée = g_nombreEntrée;
            int nombreSortie = 0;

            for (int i = 0; i != nombreEntrée.Length; ++i)
            {
                char lettre = nombreEntrée[i];      

                switch (lettre)     // Convertit chaque lettre par son équivalent en notation décimale.
                {
                    case 'M':
                        nombreSortie += 1000;
                        break;

                    case 'D': 
                        nombreSortie += 500; 
                        break;

                    case 'C':   
                        if (i != nombreEntrée.Length - 1 && nombreEntrée[i + 1] == 'M')
                        {
                            nombreSortie += 900;    // Si un C est suivi d'un M, cela vaut 900.
                            ++i;
                        }
                        else
                        if (i != nombreEntrée.Length - 1 && nombreEntrée[i + 1] == 'D')
                        {
                            nombreSortie += 400;    // Si un C est suivi d'un D, cela vaut 400.
                            ++i;
                        }
                        else
                            nombreSortie += 100;
                        break;

                    case 'L': 
                        nombreSortie += 50; 
                        break;

                    case 'X':
                        if (i != nombreEntrée.Length - 1 && nombreEntrée[i + 1] == 'C')
                        {
                            nombreSortie += 90;     // Si un X est suivi d'un C, cela vaut 90.
                            ++i;
                        }
                        else
                        if (i != nombreEntrée.Length - 1 && nombreEntrée[i + 1] == 'L')
                        {
                            nombreSortie += 40;     // Si un X est suivi d'un L, cela vaut 40.
                            ++i;
                        }
                        else
                            nombreSortie += 10;
                        break;

                    case 'V': 
                        nombreSortie += 5; 
                        break;

                    case 'I':
                        if (i != nombreEntrée.Length - 1 && nombreEntrée[i + 1] == 'X')
                        {
                            nombreSortie += 9;      // Si un I est suivi d'un X, cela vaut 9.
                            ++i;
                        }
                        else
                        if (i != nombreEntrée.Length - 1 && nombreEntrée[i + 1] == 'V')
                        {
                            nombreSortie += 4;      // Si un I est suivi d'un V, cela vaut 4.
                            ++i;
                        }
                        else
                            nombreSortie += 1;
                        break;
                }
            }

            g_nombreSortie = nombreSortie.ToString();
        }

        private void ConversionRomaineBinaire()
        {
            ConversionRomaineDecimale();        // On se sert de ce qui a déjà été fait précédemment.

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleBinaire();
        }

        private void ConversionRomaineHexadecimale()
        {
            ConversionRomaineDecimale();

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleHexadecimale();
        }

        private void ConversionRomaineLettres()
        {
            ConversionRomaineDecimale();

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleLettres();
        }

        private void ConversionRomaineArabe()
        {
            ConversionRomaineDecimale();

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleArabe();
        }

        private void ConversionRomaineMaya()
        {
            ConversionRomaineDecimale();

            g_nombreEntrée = g_nombreSortie;
            g_nombreSortie = "";

            ConversionDecimaleMaya();
        }

        private void ConversionLettresDecimale()
        { 
        
        }

        private void ConversionLettresBinaire()
        { 
        
        }

        private void ConversionLettresHexadecimale()
        { 
        
        }

        private void ConversionLettresRomaine()
        { 
        
        }

        private void ConversionLettresArabe()
        {
        
        }

        string g_nombreEntrée;      // Variables globales utilisées à plusieurs endroits dans le programme.
        string g_nombreSortie;

        private void Conversion()
        {
            g_nombreEntrée = textBoxNombreEntree.Text;      // Prend ce qui est entré par l'utilisateur
                                                             // dans la boite "Nombre à l'entrée".
            if ((RBdepartDecimale.Checked && RBarriveeDecimale.Checked)
                || (RBdepartRomaine.Checked && RBarriveeRomaine.Checked)
                || (RBdepartBinaire.Checked && RBdepartBinaire.Checked)
                || (RBdepartHexadecimale.Checked && RBarriveeHexadecimale.Checked)
                || (RBdepartLettres.Checked && RBarriveeLettres.Checked)
                || (RBdepartMaya.Checked && RBarriveeMaya.Checked)
                || (RBdepartArabe.Checked && RBarriveeArabe.Checked))
                g_nombreSortie = g_nombreEntrée;        // Il n'y a aucune conversion à effectuer.
            
            if (RBdepartDecimale.Checked && RBarriveeRomaine.Checked)   // Effectue les conversions selon
                ConversionDecimaleRomaine();                             // les boutons radio cochés par
                                                                         // l'utilisateur
            if (RBdepartDecimale.Checked && RBarriveeBinaire.Checked)
                ConversionDecimaleBinaire();
            
            if (RBdepartDecimale.Checked & RBarriveeHexadecimale.Checked)
                ConversionDecimaleHexadecimale();

            if (RBdepartDecimale.Checked && RBarriveeLettres.Checked)
                ConversionDecimaleLettres();

            if (RBdepartDecimale.Checked && RBarriveeArabe.Checked)
                ConversionDecimaleArabe();

            if (RBdepartDecimale.Checked && RBarriveeMaya.Checked)
                ConversionDecimaleMaya();

            if (RBdepartBinaire.Checked && RBarriveeDecimale.Checked)
                ConversionBinaireDecimale();

            if (RBdepartBinaire.Checked && RBarriveeHexadecimale.Checked)
                ConversionBinaireHexadecimale();

            if (RBdepartBinaire.Checked && RBarriveeRomaine.Checked)
                ConversionBinaireRomaine();

            if (RBdepartBinaire.Checked && RBarriveeLettres.Checked)
                ConversionBinaireLettres();

            if (RBdepartBinaire.Checked && RBarriveeArabe.Checked)
                ConversionBinaireArabe();

            if (RBdepartBinaire.Checked && RBarriveeMaya.Checked)
                ConversionBinaireMaya();

            if (RBdepartHexadecimale.Checked && RBarriveeDecimale.Checked)
                ConversionHexadecimaleDecimale();

            if (RBdepartHexadecimale.Checked && RBarriveeBinaire.Checked)
                ConversionHexadecimaleBinaire();

            if (RBdepartHexadecimale.Checked && RBarriveeRomaine.Checked)
                ConversionHexadecimaleRomaine();

            if (RBdepartHexadecimale.Checked && RBarriveeLettres.Checked)
                ConversionHexadecimaleLettres();

            if (RBdepartHexadecimale.Checked && RBarriveeArabe.Checked)
                ConversionHexadecimaleArabe();

            if (RBdepartHexadecimale.Checked && RBarriveeMaya.Checked)
                ConversionHexadecimaleMaya();

            if (RBdepartRomaine.Checked && RBarriveeDecimale.Checked)
                ConversionRomaineDecimale();

            if (RBdepartRomaine.Checked && RBarriveeBinaire.Checked)
                ConversionRomaineBinaire();

            if (RBdepartRomaine.Checked && RBarriveeHexadecimale.Checked)
                ConversionRomaineHexadecimale();

            if (RBdepartRomaine.Checked && RBarriveeLettres.Checked)
                ConversionRomaineLettres();

            if (RBdepartRomaine.Checked && RBarriveeArabe.Checked)
                ConversionRomaineArabe();

            if (RBdepartRomaine.Checked && RBarriveeMaya.Checked)
                ConversionRomaineMaya();

            if (RBdepartLettres.Checked && RBarriveeDecimale.Checked)
                ConversionLettresDecimale();

            if (RBdepartLettres.Checked && RBarriveeBinaire.Checked)
                ConversionLettresBinaire();

            if (RBdepartLettres.Checked && RBarriveeHexadecimale.Checked)
                ConversionLettresHexadecimale();

            if (RBdepartLettres.Checked && RBarriveeRomaine.Checked)
                ConversionLettresRomaine();

            if (RBdepartLettres.Checked && RBarriveeArabe.Checked)
                ConversionLettresArabe();


            textBoxNombreSortie.Text = g_nombreSortie;    // Renvoie le nombre converti dans la boite
        }                                                  // "Nombre à la sortie".

        private void BoutonConvertir_Click(object sender, EventArgs e)
        {
            textBoxNombreSortie.Text = "";      // En cliquant sur le bouton "Convertir", le programme
            g_nombreEntrée = "";                 // vide les variables globales ainsi que la boite "Nombre
            g_nombreSortie = "";                 // à la sortie".   

            if (VérificationErreurs())          // S'il n'y a pas d'erreur, le programme procède à la conversion
                Conversion();                    // demandée par l'utilisateur.
        }

        private void proposToolStripMenuItem_Click(object sender, EventArgs e)
        {
            FormMessage boite = new FormMessage("Programme conçu par Stéphanie Besner-Depocas, " +
                "Jinane Fahs et Valantina Jeji dans le cadre du cours MAT4812, hiver 2010, UQÀM");
            boite.Text = "À propos";
            boite.ShowDialog();
        }

        // On permet à l'utilisateur d'appuyer sur la touche "Enter" pour effectuer la conversion.
        private void textBoxNombreEntree_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Enter)
            {
                BoutonConvertir.PerformClick();
                e.Handled = true;
            }
        }
    }
}
